@@ -14,15 +14,14 @@
     #include <config.h>
 #endif
 
-#include "compat.h"
+#include "compat/compat.h"
 
 #include <stdlib.h>
 #include <stdio.h>                      /* for rewind, FILE */
 
 #include <png.h>
 
-#include "log.h"
-#include "driftnet.h"
+#include "common/log.h"
 #include "img.h"
 #include "pngformat.h"
 
@@ -32,7 +31,7 @@ void png_catch_error(png_structp png_ptr, png_const_charp error_msg)
 
    if (setjmp(png_jmpbuf(png_ptr))) {
 	  log_msg(LOG_ERROR, "libpng, unrecoverable error, terminating.");
-      unexpected_exit(-1);
+      abort();
    }
 }
 
@@ -93,7 +92,8 @@ int png_abort_load(img I) {
 }
 
 int png_load_img(img I) {
-    unsigned char **p, **q;
+    pel **p;
+    unsigned char **q;
     png_structp png_ptr;
     png_infop info_ptr;
     png_uint_32 width, height;
@@ -169,12 +169,12 @@ int png_load_img(img I) {
     /* Read in the image and copy it to the gdk img structure */
     png_read_image(png_ptr, row_pointers);
 
-    p = (unsigned char **)I->data;
+    p = I->data;
     q = (unsigned char **)row_pointers;
 
     for (i = 0; i < height; i++) {
-        for (j = 0; j < png_get_rowbytes(png_ptr, info_ptr); j++) {
-           p[i][j] = q[i][j];
+        for (j = 0; j < png_get_rowbytes(png_ptr, info_ptr); j = j+4) {
+            p[i][j/4] = PEL(q[i][j], q[i][j+1], q[i][j+2]);
         }
     }
 
