@@ -1,5 +1,5 @@
 /*
- * png.h:
+ * pngformat.h:
  * Png file handling.
  *
  * Copyright (c) 2012 David Suárez.
@@ -13,7 +13,7 @@
 #ifdef HAVE_CONFIG_H
     #include <config.h>
 #endif
-#include "compat.h"
+#include "compat/compat.h"
 
 #define PNG_CODE_LEN 4
 #define PNG_CRC_LEN  4
