@@ -2,7 +2,7 @@
  * options.h:
  * Options parsing.
  *
- * Copyright (c) 2012 David Suárez.
+ * Copyright (c) 2024 David Suárez.
  * Email: david.sephirot@gmail.com
  *
  */
@@ -26,13 +26,14 @@
 
 #include "options.h"
 
-options_t options = {NULL, FALSE, 0, TRUE, FALSE, FALSE, FALSE, TRUE,
-        NULL, NULL, NULL, MEDIATYPE_IMAGE, NULL, FALSE, FALSE,
+options_t options = {
+    NULL, FALSE, 0, TRUE, FALSE, FALSE,FALSE, FALSE, TRUE,
+    NULL, NULL, NULL, MEDIATYPE_IMAGE, NULL, FALSE, FALSE,
 #ifndef NO_DISPLAY_WINDOW
-        "driftnet-",
-        FALSE,
+    "driftnet-",
+    FALSE,
 #endif
-        NULL, 0, 0, FALSE, 9090
+    NULL, 0, 0, FALSE, 9090, 0
 };
 
 static int validate_options(options_t* options);
@@ -43,8 +44,9 @@ static void usage(FILE *fp);
  */
 options_t* parse_options(int argc, char *argv[])
 {
-    char optstring[] = "abd:f:hi:M:m:pSsvx:Z:lr:wW:g";
+    char optstring[] = "abd:f:hi:M:m:pSsvDx:Z:lr:wW:gy:tT";
     int c;
+    mediatype_t specific_media = 0;
 
     opterr = 0;
     while ((c = getopt(argc, argv, optstring)) != -1) {
@@ -65,6 +67,10 @@ options_t* parse_options(int argc, char *argv[])
                 options.verbose = TRUE;
                 break;
 
+            case 'D':
+                options.debug = TRUE;
+                break;
+
             case 'b':
                 if (!isatty(1))
                     log_msg(LOG_WARNING, "can't beep unless standard output is a terminal");
@@ -81,9 +87,27 @@ options_t* parse_options(int argc, char *argv[])
                 break;
 
             case 'S':
+                if (specific_media == MEDIATYPE_TEXT) {
+                    log_msg(LOG_ERROR, "text only capture already selected");
+                    return NULL;
+                }
+                specific_media = MEDIATYPE_AUDIO;
                 options.extract_type = MEDIATYPE_AUDIO;
                 break;
 
+            case 't':
+                options.extract_type |= MEDIATYPE_TEXT;
+            break;
+
+            case 'T':
+                if (specific_media == MEDIATYPE_AUDIO) {
+                    log_msg(LOG_ERROR, "audio only capture already selected");
+                    return NULL;
+                }
+                specific_media = MEDIATYPE_TEXT;
+                options.extract_type = MEDIATYPE_TEXT;
+            break;
+
             case 'M':
                 options.audio_mpeg_player = optarg;
                 options.mpeg_player_specified = TRUE;
@@ -148,6 +172,10 @@ options_t* parse_options(int argc, char *argv[])
                 break;
 #endif
 
+            case 'y':
+                options.offline_delay = atoi(optarg);
+                break;
+
             case '?':
             default:
                 if (strchr(optstring, optopt))
@@ -265,6 +293,10 @@ int validate_options(options_t* options)
 #endif
     }
 
+    if (options->verbose && options->debug) {
+        log_msg(LOG_WARNING, "verbose and debug are mutually exclusive: switching to debug mode anyway");
+    }
+
     return TRUE;
 }
 
@@ -282,6 +314,7 @@ void usage(FILE *fp)
 "\n"
 "  -h               Display this help message.\n"
 "  -v               Verbose operation.\n"
+"  -D               Debug operation.\n"
 "  -b               Beep when a new image is captured.\n"
 "  -i interface     Select the interface on which to listen (default: all\n"
 "                   interfaces).\n"
@@ -299,7 +332,11 @@ void usage(FILE *fp)
 "  -s               Attempt to extract streamed audio data from the network,\n"
 "                   in addition to images. At present this supports MPEG data\n"
 "                   only.\n"
-"  -S               Extract streamed audio but not images.\n"
+"  -S               Extract streamed audio only.\n"
+"  -t               Attempt to extract text data from the network,\n"
+"                   in addition to images. At present this supports HTTP request\n"
+"                   only.\n"
+"  -T               Extract text data only.\n"
 "  -M command       Use the given command to play MPEG audio data extracted\n"
 "                   with the -s option; this should process MPEG frames\n"
 "                   supplied on standard input. Default: `mpg123 -'.\n"
@@ -313,6 +350,7 @@ void usage(FILE *fp)
 "  -w               Enable the HTTP server to display images.\n"
 "  -W               Port number for the HTTP server (implies -w). Default: 9090.\n"
 #endif
+"  -y miliseconds   In offline mode, use specified miliseconds delay between packets.\n"
 "\n"
 "Filter code can be specified after any options in the manner of tcpdump(8).\n"
 "The filter code will be evaluated as `tcp and (user filter code)'\n"
